@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.6/classes/src/DwmDnsRRDataLOC.cc 10138 $
-// @(#) $Id: DwmDnsRRDataLOC.cc 10138 2018-01-28 07:39:44Z dwm $
+// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsRRDataLOC.cc 12365 $
+// @(#) $Id: DwmDnsRRDataLOC.cc 12365 2024-05-22 21:47:33Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2000, 2016, 2018
 //  All rights reserved.
@@ -50,7 +50,7 @@ extern "C" {
 #include "DwmSvnTag.hh"
 #include "DwmDnsRRDataLOC.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.6/classes/src/DwmDnsRRDataLOC.cc 10138 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.7/classes/src/DwmDnsRRDataLOC.cc 12365 $");
 
 using namespace std;
 
@@ -75,7 +75,7 @@ namespace Dwm {
       
       val = mantissa * poweroften[exponent];
       
-      (void) sprintf(retbuf,"%ld.%.2ld", val/100, val%100);
+      (void) snprintf(retbuf, sizeof(retbuf), "%ld.%.2ld", val/100, val%100);
       return (retbuf);
     }
 
